<?php // $Id$

/**
*  @file 
*  Actions callback for Views Bulk Operations support
*/

/**
*  Implementation of hook_action_info
*/
function nodereference_basket_action_info() {
  $actions['nodereference_basket_action'] = array(
    'description' => t('Add to reference basket'),
    'type' => 'system',
    'configurable' => TRUE,
    'behavior' => array('changes node property'),
  );

  return $actions;
}

/**
*  Settings form for Views Bulk Operations - allows the user to select
*  the field they would like to add the selected nodes to.
*  @todo - This should be skipped if there's only one field
*/
function nodereference_basket_action_form($context) {
  $form['#settings'] = $context['settings'];
  if (!$_SESSION['nodereference_basket_nid']) {
    drupal_set_message(t('You must first have a basket started from another post.'));
    return NULL;
  }
  $add_node = node_load($_SESSION['nodereference_basket_nid']);
  $form['fields'] = array(
    '#type' => 'fieldset',
    '#title' => t('Add to %title', array('%title' => $add_node->title)),
  );
  foreach ($_SESSION['nodereference_basket_fields'] as $field_name => $field) {
    $form['fields'][$field_name] = array(
      '#type' => 'checkbox',
      '#title' => t('Add to field @field', array('@field' => $field['field']['widget']['label'])),
    );
  }
  return $form;
}

/**
*  Validation callback. Check that at least one field is selected.
*/
function nodereference_basket_action_validate($form, $form_state) {
  $set = FALSE;
  foreach ($_SESSION['nodereference_basket_fields'] as $field_name => $field) {
    if ($form_state['values'][$field_name]) {
      $set = TRUE;
    }
  }
  if (!$set) {
    form_set_error('', t('You must select at least one field from the basket.'));
  }
}

/**
*  Submit callback. Add the selected fields to the action context. We prefix these 
*  with 'basket_' to prevent clobbering other values.
*/
function nodereference_basket_action_submit($form, $form_state) {
  $values = array();
  foreach ($_SESSION['nodereference_basket_fields'] as $field_name => $field) {
    $values['basket_'. $field_name] = $form_state['values'][$field_name];
  }
  return $values;
}

/**
*  The action callback. Make sure that the node doesn't exist in each field, and if
*  not, add it.
*/
function nodereference_basket_action(&$node, $context) {
  foreach ($_SESSION['nodereference_basket_fields'] as $field_name => $field) {
    if ($context['basket_'. $field_name]) {
      $set = TRUE;
      foreach ($field['values'] as $value) {
        if ($value['nid'] == $node->nid) {
          $set = FALSE;
        }
      }
      if ($set) {
        $_SESSION['nodereference_basket_fields'][$field_name]['values'][] = array('nid' => $node->nid);
      }
    }
  }
}